vertexai
========

To use the Vertex GAPIC clients, please install the `google-cloud-aiplatform` PyPi package by running `pip install google-cloud-aiplatform`.

To use the Vertex AI SDK, please install the `vertexai` PyPi package by running `pip install vertexai`.